<?xml version="1.0" encoding="utf-8"?>
<!-- @file componentResultsFormatting.xsl

@brief Used to format the results produced by the fwUnitTestComponent.
  
@par Creation Date
		 04/04/2014   
  
-->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
  <xsl:output method="html" media-type="text/xml" />
  
  <xsl:variable name="red">#FF9999</xsl:variable>
  <xsl:variable name="green">#99FF99</xsl:variable>
  
  <!-- 
	Template to write all the failed tests. 
  -->
  <xsl:template name="failedTestsOnly">
	<table>							
		<xsl:for-each select="//testsuite"><xsl:choose><xsl:when test="@failures &gt; 0">
			<xsl:call-template name="writeTestSuite"></xsl:call-template>
			<!-- Write the test cases -->
			<xsl:for-each select="testcase">																
				<tr><xsl:choose><xsl:when test= "failure/@message">	
					<xsl:call-template name="writeFailedCase"></xsl:call-template>							
				</xsl:when></xsl:choose></tr>												
			</xsl:for-each>								
		</xsl:when></xsl:choose></xsl:for-each>					
		<tr><td height="5px" colspan="3"></td></tr>				
	</table>
  </xsl:template>
  
  <!--  -->
  
  <!-- 
	Template to write the name of a test suite and the table headers. 
  -->
  <xsl:template name="writeTestSuite">
	<!-- Set the color of the test suite -->
	<xsl:variable name="textColour2">
		<xsl:choose>
			<xsl:when test="@failures &lt;= 0"><xsl:value-of select="$green"/></xsl:when>
			<xsl:otherwise><xsl:value-of select="$red"/></xsl:otherwise>
		</xsl:choose>			
	</xsl:variable>
	
	<tr ><td height="5px" colspan="3"></td></tr>
	
	<!-- Write the test suite -->			
	<tr>	
	<xsl:element name="th">					
		<xsl:attribute name="bgcolor"><xsl:value-of select="$textColour2"/></xsl:attribute><xsl:attribute name="colspan">3</xsl:attribute>
			<xsl:value-of select="substring-after(@name, '.')"/>							
			 &#160;: &#160;<xsl:value-of select="@failures"/>/<xsl:value-of select="@tests"/> tests failed,&#160;&#160; in <xsl:value-of select="@time"/> seconds 
	</xsl:element>		
	</tr>					
	<tr><th class="head" colspan="1">Test Name</th><th class="head">Message</th><th class="head">Time (seconds)</th></tr>
  </xsl:template>
  
  <!-- -->
  
  <!-- 
	Template to write a failed test case. 
  -->
  <xsl:template name="writeFailedCase">    															
		<xsl:element name="td">	 <xsl:attribute name="class">indent</xsl:attribute> <xsl:attribute name="bgcolor"><xsl:value-of select="$red"/></xsl:attribute> <xsl:value-of select="@name"/></xsl:element> 
		<xsl:element name="td">	 <xsl:attribute name="bgcolor"><xsl:value-of select="$red"/></xsl:attribute> <xsl:value-of select="failure/@message"/></xsl:element> 
		<xsl:element name="td">	 <xsl:attribute name="class">num</xsl:attribute><xsl:attribute name="bgcolor"><xsl:value-of select="$red"/></xsl:attribute> <xsl:value-of select="@time"/> </xsl:element>		
  </xsl:template>
  
  <!-- -->
  
  <!-- 
	Template to write a passed test case. 
  -->
  <xsl:template name="writePassedCase">    															
		<xsl:element name="td">  <xsl:attribute name="class">indent</xsl:attribute> <xsl:attribute name="bgcolor"><xsl:value-of select="$green"/></xsl:attribute><xsl:value-of select="@name"/> </xsl:element> 
		<xsl:element name="td">	 <xsl:attribute name="bgcolor"><xsl:value-of select="$green"/></xsl:attribute>Test passed</xsl:element> 
		<xsl:element name="td">	 <xsl:attribute name="class">num</xsl:attribute> <xsl:attribute name="bgcolor"><xsl:value-of select="$green"/></xsl:attribute> <xsl:value-of select="@time"/> </xsl:element>							
  </xsl:template>
  
  <!-- -->
  
  <xsl:template match="/">
    <html>
		<head>
			<style type="text/css">
				table, th, td, h1, h2, h3, p, a
				{
					font-family: Arial,sans-serif;
				}				
				table, th, td
				{		
					font-size:12px;
					border: 1px solid #BBBBBB;									
					border-collapse:collapse;
					text-align:left;	
					margin-top:3px;
					margin-bottom:3px;
				}				
				table
				{
					border: 1px solid #BBBBBB;
					width:100%;	
					border-left: 2px solid #CCCCCC;	
					border-right: 2px solid #CCCCCC;					
				}				
				th.head
				{
					border: 1px solid #BBBBBB; 
					border-bottom: 1px solid #FFFFFF; 
					text-align:center; 				
				}
				th, td, th.head
				{
					border-left: 0px solid #CCCCCC;	
					border-right: 0px solid #CCCCCC;
					padding-left:7px;
					padding-right:3px;
				}				
				td.indent
				{
					padding-left:30px;
				}				
				td.num
				{
					text-align:right;
				}								
			</style>
		</head>
	
        <body>
			<h1>Unit Testing Results</h1>
			
			<!-- Set the component name's color -->
			<xsl:variable name="textColour">
				<xsl:choose>
					<xsl:when test="//@failures[1] &gt; 0"><xsl:value-of select="$red"/></xsl:when>
					<xsl:otherwise><xsl:value-of select="$green"/></xsl:otherwise>
				</xsl:choose>			
			</xsl:variable>
			<!-- Write the component name --> <!--TODO work out why the text colour is not working-->
			<h2><xsl:element name="span">					
					<!--<xsl:attribute name="style">background-color:<xsl:value-of select="$textColour"/></xsl:attribute>	-->								
					<xsl:value-of select="//@name[1]"/> : <xsl:value-of select="//@failures[1]"/>/<xsl:value-of select="//@tests[1]"/>  tests failed
			</xsl:element></h2>
			
			<h3>All failed tests </h3>	
			<xsl:call-template name="failedTestsOnly"></xsl:call-template>			

			<h3>All tests</h3>
			<table>							
				<xsl:for-each select="//testsuite">
					<xsl:call-template name="writeTestSuite"></xsl:call-template>
					<!-- Write the test cases -->
					<xsl:for-each select="testcase">
					<tr>													
						<xsl:choose>
							<!-- Write a failed test case -->
							<xsl:when test= "failure/@message">															
								<xsl:call-template name="writeFailedCase"></xsl:call-template>	
							</xsl:when>
							<!-- Write a passed test case -->
							<xsl:otherwise>	
								<xsl:call-template name="writePassedCase"></xsl:call-template>													
							</xsl:otherwise>
						</xsl:choose>							
					</tr>							
					</xsl:for-each>					
					
				</xsl:for-each>					
				<tr><td height="5px" colspan="3"></td></tr>				
			</table>
	    </body>
	</html>	
  </xsl:template>   	
	
</xsl:stylesheet>

